@@ -4,11 +4,11 @@
  * GChemPaint library
  * arrow.h
  *
- * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -196,6 +196,9 @@ This method must be called from derived classes overloaded Save methods.
 */
 	bool Save (xmlDocPtr xml, xmlNodePtr node) const;
 
+/*!
+@return "Arrow" (actually it is localized).
+*/
 	std::string Name ();
 
 /*!
@@ -224,6 +227,9 @@ The y coordinate difference between tail and head.
 private:
 	Step *m_Start, *m_End;
 
+/*!\fn GetLength
+@return the arrow length.
+*/
 GCU_RO_PROP (double, Length)
 };
 
