@@ -1,12 +1,12 @@
-/* 
+/*
  * GChemPaint library
- * fontsel.h 
+ * fontsel.h
  *
  * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -34,17 +34,17 @@ G_BEGIN_DECLS
 typedef struct _GcpFontSel GcpFontSel;
 
 /*!@return the GType associated to GcpFontSel */
-#define GCP_FONT_SEL_TYPE     (gcp_font_sel_get_type ())
+#define GCP_TYPE_FONT_SEL     (gcp_font_sel_get_type ())
 /*!
 Casts \a obj to a GcpFontSel * pointer.
-@return a pointer to the GcpFontSel * or NULL if \a obj does not point to 
+@return a pointer to the GcpFontSel * or NULL if \a obj does not point to
 a GcpFontSel widget.
 */
-#define GCP_FONT_SEL(obj)     (G_TYPE_CHECK_INSTANCE_CAST ((obj), GCP_FONT_SEL_TYPE, GcpFontSel))
+#define GCP_FONT_SEL(obj)     (G_TYPE_CHECK_INSTANCE_CAST ((obj), GCP_TYPE_FONT_SEL, GcpFontSel))
 /*!
 \return TRUE if \a obj points to a GcpFontSel widget, FALSE otherwise.
 */
-#define IS_GCP_FONT_SEL(obj)  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GCP_FONT_SEL_TYPE))
+#define IS_GCP_FONT_SEL(obj)  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GCP_TYPE_FONT_SEL))
 
 /*!@return the GType associated to GcpFontSel */
 GType gcp_font_sel_get_type (void);
@@ -69,7 +69,7 @@ This signal is raised when any property changes in the widget.
 There are six properties:
 - "family": char* (Read / Write).
 	<br>The font family. Default is "Bitstream Vera Sans".
-	
+
 - "style": PangoStyle (Read / Write).
 	<br>The font style. Default is PANGO_STYLE_NORMAL.
 
@@ -84,6 +84,12 @@ There are six properties:
 
 - "size": int (Read / Write).
 	<br>The font size expressed in pango units. Default is 12*PANGO_SCALE.
+
+- "allow-slanted": gboolean (Construct only).
+	<br>Whether to allow slanted fonts. Default is TRUE.
+
+- "label": string (Read / Write).
+	<br>The preview text. Default is the font description.
 */
 
 G_END_DECLS
