@@ -4,11 +4,11 @@
  * GChemPaint library
  * mechanism-step.h
  *
- * Copyright (C) 2009-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2009-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -27,7 +27,7 @@
 
 /*!\file*/
 
-#include <gcu/object.h>
+#include <gcp/step.h>
 
 namespace gcp {
 
@@ -38,8 +38,9 @@ extern gcu::TypeId MechanismStepType;
 
 One or several molecules with mechanism arrows joining them.
 */
-class MechanismStep: public gcu::Object
+class MechanismStep: public Step
 {
+friend class MechanismStepPrivate;
 public:
 /*!
 Constructs a new MechanismStep.
@@ -89,9 +90,20 @@ Used to load a mechanism step in memory. The MechanismStep must already exist.
 Destroys the MechanismStep when empty.
 */
 	void NotifyEmpty ();
+/*!
+@param UIManager the gcu::UIManager to populate.
+@param object the Object on which occured the mouse click.
+@param x x coordinate of the mouse click.
+@param y y coordinate of the mouse click.
+
+This method is called to build the contextual menu for the mechanism step.
+@return true if something is added to the UIManager, false otherwise.
+*/
+	bool BuildContextualMenu (gcu::UIManager *UIManager, gcu::Object *object, double x, double y);
 
 private:
 	bool m_bLoading;
+	gcu::Object *m_Alignment;
 };
 
 }	//	namespace gcp
