@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint libray
- * settings.h 
+ * settings.h
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -25,9 +25,7 @@
 #ifndef GCHEMPAINT_SETTINGS_H
 #define GCHEMPAINT_SETTINGS_H
 
-#include <glib.h>
-#include <pango/pango.h>
-#include <goffice/utils/go-color.h>
+#include <goffice/goffice.h>
 
 #define ROOTDIR "/apps/gchemutils/paint/settings/"
 #define GCP_CONF_DIR_SETTINGS "paint/settings"
@@ -64,10 +62,6 @@ extern bool MergeAtoms;
 XML file compression level.
 */
 extern int CompressionLevel;
-/*!
-Whether the mendeleiv table widget might be detached from the tool box or not.
-*/
-extern bool TearableMendeleiev;
 
 /*!
 Clipboard formats identifiers
@@ -126,6 +120,13 @@ should be either GCP_CLIPBOARD_NO_TEXT or GCP_CLIPBOARD_ALL
 */
 extern int ClipboardFormats;
 
+/*!
+Hashed bonds are normally represented with the large side nearest, which is
+the opposite of what many people want. Setting InvertWedgeHashes to true will
+change this behavior. Default is false.
+*/
+extern bool InvertWedgeHashes;
+
 }	//	namespace gcp
 
 #endif // GCHEMPAINT_SETTINGS_H
