@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint libray
- * text-object.h 
+ * text-object.h
  *
  * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -33,6 +33,10 @@
 #include <pango/pango-layout.h>
 #include <string>
 
+namespace gccv {
+	class Text;
+}
+
 /*!\file*/
 namespace gcp {
 
@@ -192,14 +196,6 @@ the selection.
 */
 	bool m_RealSave;
 
-/*!\var m_Anchor
-The GtkAnchor used for the text object. Default is GTK_ANCHOR_W. When
-GTK_ANCHOR_W, GTK_ANCHOR_CENTER, or GTK_ANCHOR_E is used, the base of the
-first line is used for vertical alignment.
-*/
-/*!\fn GetAnchor()
-@return the current GtkAnchor.
-*/
 //GCU_PROT_PROP (GtkAnchorType, Anchor)
 /*!\var m_TagList
 The tags list associated with the object.
@@ -208,7 +204,27 @@ The tags list associated with the object.
 @return a copy of the tags list for this object.
 */
 GCU_PROT_PROP (gccv::TextTagList, TagList)
+
+/*!\fn SetEditor(TextEditor *val)
+@param val the text editor associated with the object during edition.
+
+Associates \a val with the object during edition.
+*/
+/*!\fn GetEditor()
+@return the associated text editor.
+*/
+/*!\fn GetRefEditor()
+@return the associated text editor as a reference.
+*/
 GCU_PROP (TextEditor*, Editor)
+
+/*!\var m_TextItem
+The canvas text item used to display the object.
+*/
+/*!\fn GetTextItem
+@return the canvas text item used to display the object.
+*/
+GCU_PROT_PROP (gccv::Text*, TextItem)
 };
 
 }	// namespace gcp
