@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -30,6 +30,7 @@
 #include "cylinder.h"
 #include "glview.h"
 #include "loader.h"
+#include "objprops.h"
 #include "sphere.h"
 #include "vector.h"
 #include <gcu/chemistry.h>
@@ -82,14 +83,14 @@ char const *Chem3dDoc::Display3DModeAsString (Display3DMode mode)
 
 Chem3dDoc::Chem3dDoc (): GLDocument (Application::GetDefaultApplication ())
 {
-	m_View = CreateView ();
+	m_View = NULL;
 	m_Display3D = BALL_AND_STICK;
 	m_Mol = NULL;
 }
 
 Chem3dDoc::Chem3dDoc (Application *App, GLView *View): GLDocument (App)
 {
-	m_View = (View)? View: CreateView ();
+	m_View = View;
 	m_Display3D = BALL_AND_STICK;
 	m_Mol = NULL;
 }
@@ -153,6 +154,27 @@ void Chem3dDoc::Load (char const *uri, char const *mime_type)
 	string filename = uri;
 	Clear ();
 	ContentType type = app->Load (filename, mime_type, this);
+	if (type == ContentTypeCrystal) {
+		// convert atoms coordinates using the cell parameters
+		std::map<std::string, Object*>::iterator it;
+		obj =  GetFirstChild (it);
+		while (obj) {
+			m_Mol = dynamic_cast <Molecule *> (obj);
+			if (m_Mol)
+				break;
+			obj = GetNextChild (it);
+		}
+		if (m_Mol) {
+			std::list<Atom*>::iterator a;
+			Atom *atom = m_Mol->GetFirstAtom (a);
+			double alpha = m_alpha * M_PI / 180;
+			double beta = m_beta * M_PI / 180;
+			double gamma = m_gamma * M_PI / 180;
+			for (; atom; atom = m_Mol->GetNextAtom (a))
+				atom->NetToCartesian (m_a, m_b, m_c, alpha, beta, gamma);
+			type = ContentType3D;
+		}
+	}
 	Loaded ();
 	if (type == ContentType3D) {
 		// center the scene around 0,0,0
@@ -184,6 +206,7 @@ void Chem3dDoc::Load (char const *uri, char const *mime_type)
 			SetTitle (fn);
 			g_free (fn);
 		}
+		ChangedDisplay3D ();
 		m_View->Update ();
 	} else if (type != ContentTypeUnknown) {
 		Clear ();
@@ -192,7 +215,7 @@ void Chem3dDoc::Load (char const *uri, char const *mime_type)
 	g_object_unref (file);
 }
 
-void Chem3dDoc::LoadData (char const *data, char const *mime_type, size_t size)
+ContentType Chem3dDoc::LoadData (char const *data, char const *mime_type, size_t size)
 {
 	bool need_free = false;
 	if (!mime_type) {
@@ -201,7 +224,7 @@ void Chem3dDoc::LoadData (char const *data, char const *mime_type, size_t size)
 	}
 	if (!mime_type) {
 		// should not happen
-		return;
+		return ContentTypeUnknown;
 	}
 	if (size == 0)
 		size = strlen (data);
@@ -245,6 +268,7 @@ void Chem3dDoc::LoadData (char const *data, char const *mime_type, size_t size)
 		char const *title = m_Mol->GetName ();
 		if (title)
 			SetTitle (title);
+		ChangedDisplay3D ();
 		m_View->Update ();
 	} else if (type != ContentTypeUnknown) {
 		Clear ();
@@ -253,6 +277,7 @@ void Chem3dDoc::LoadData (char const *data, char const *mime_type, size_t size)
 	if (need_free)
 		g_free (const_cast <char *> (mime_type));
 	g_object_unref (input);
+	return type;
 }
 
 struct VrmlBond {
@@ -429,8 +454,7 @@ void Chem3dDoc::Draw (Matrix const &m) const
 	std::list <Atom *>::const_iterator i;
 	Atom const *atom = m_Mol->GetFirstAtom (i);
 	unsigned int Z;
-	gdouble R, w, x, y, z, dist;
-	dist = 0.;
+	gdouble R;
 	map<Atom const *, Vector> atomPos;
 	const gdouble* color;
 	Vector v, normal (0., 0., 1.);
@@ -464,12 +488,7 @@ void Chem3dDoc::Draw (Matrix const &m) const
 				if (m_Display3D == BALL_AND_STICK)
 					R *= 0.2;
 			}
-			x = v.GetX ();
-			y = v.GetY ();
-			z = v.GetZ ();
 			color = gcu_element_get_default_color (Z);
-			if ((w = sqrt (x * x + y * y + z * z)) > dist - R)
-				dist = w + R;
 			if (m_Display3D != WIREFRAME) {
 				glColor3d (color[0], color[1], color[2]);
 				sp.draw (v, R);
@@ -477,7 +496,6 @@ void Chem3dDoc::Draw (Matrix const &m) const
 		}
 		atom = m_Mol->GetNextAtom (i);
 	}
-	const_cast <Chem3dDoc *> (this)->m_MaxDist = dist * 1.05;
 	if (m_Display3D != SPACEFILL) {
 		Cylinder cyl (10);
 		std::list <Bond *>::const_iterator j;
@@ -546,9 +564,68 @@ void Chem3dDoc::Clear ()
 	m_Mol = NULL;
 }
 
-GLView *Chem3dDoc::CreateView ()
+void Chem3dDoc::ChangedDisplay3D ()
 {
-	return NULL;
+	if (!m_Mol)
+		return;
+	std::list <Atom *>::const_iterator i;
+	Atom const *atom = m_Mol->GetFirstAtom (i);
+	unsigned int Z;
+	gdouble R, w, x, y, z;
+	GcuAtomicRadius rad;
+	rad.type = GCU_VAN_DER_WAALS;
+	rad.charge = 0;
+	rad.cn = -1;
+	rad.spin = GCU_N_A_SPIN;
+	rad.scale = NULL;
+	m_MaxDist = 0;
+	while (atom) {
+		Z = atom->GetZ ();
+		if (Z > 0) {
+			if (m_Display3D == CYLINDERS) {
+				R = 12.;
+			} else if (m_Display3D == WIREFRAME) {
+				R = 0.;
+			} else {
+				rad.Z = Z;
+				Element::GetElement (Z)->GetRadius (&rad);
+				R = rad.value.value;
+				if (m_Display3D == BALL_AND_STICK)
+					R *= 0.2;
+			}
+			atom->GetCoords (&x, &y, &z);
+			if ((w = sqrt (x * x + y * y + z * z)) > m_MaxDist - R)
+				m_MaxDist = w + R;
+		}
+		atom = m_Mol->GetNextAtom (i);
+	}
+}
+
+bool Chem3dDoc::SetProperty (unsigned property, char const *value)
+{
+	switch (property) {
+	case GCU_PROP_CELL_A:
+		m_a = g_ascii_strtod (value, NULL) * GetScale ();
+		break;
+	case GCU_PROP_CELL_B:
+		m_b = g_ascii_strtod (value, NULL) * GetScale ();
+		break;
+	case GCU_PROP_CELL_C:
+		m_c = g_ascii_strtod (value, NULL) * GetScale ();
+		break;
+	case GCU_PROP_CELL_ALPHA:
+		m_alpha = g_ascii_strtod (value, NULL);
+		break;
+	case GCU_PROP_CELL_BETA:
+		m_beta = g_ascii_strtod (value, NULL);
+		break;
+	case GCU_PROP_CELL_GAMMA:
+		m_gamma = g_ascii_strtod (value, NULL);
+		break;
+	default:
+		return false;
+	}
+	return true;
 }
 
 }	//	namespace gcu
