@@ -4,11 +4,11 @@
  * Gnome Chemistry Utils
  * gcu/chem3ddoc.h
  *
- * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -103,7 +103,7 @@ the string length.
 
 Loads a molecule from the provided data.
 */
-	void LoadData (char const *data, char const *mime_type, size_t size = 0);
+	ContentType LoadData (char const *data, char const *mime_type, size_t size = 0);
 
 /*!
 @param filename the name of the vrml file to which the data should be written.
@@ -116,11 +116,40 @@ Exports the embedded molecule as a vrml scene.
 Clears the document.
 */
 	void Clear ();
-	virtual GLView *CreateView ();
 
+/*!
+	 Pure virtual method used to create a view. Must be overriden in derived classes.
+
+@return the newly created view.
+*/
+	virtual GLView *CreateView () = 0;
+
+/*!
+@param name the name of the display mode.
+
+Converts a string to an actual display mode. Supported names are: "ball&stick",
+"spacefill", "cylinders", and "wireframe".
+@return the display mode or BALL_AND_STICK on error.
+
+*/
 	static Display3DMode Display3DModeFromString (char const *name);
+
+/*!
+@param mode a display mode.
+
+@return a string representation of the display mode.
+*/
 	static char const *Display3DModeAsString (Display3DMode mode);
 
+/*!
+@param property the property id as defined in objprops.h
+@param value the property value as a string
+
+Used when loading to set properties to the document
+@return true if the property could be set, or if the property is not relevant, false otherwise.
+*/
+	bool SetProperty (unsigned property, char const *value);
+
 /*!\fn SetDisplay3D(Display3DMode mode)
 @param mode: the new mode.
 
@@ -129,11 +158,15 @@ Sets the display mode to one of the available Display3DMode values.
 /*!\fn GetDisplay3D()
 @return the current mode.
 */
-/*!\fn GetRefDisplay3D()
-@return the current mode as a reference.
+GCU_PROP_EX (Display3DMode, Display3D)
+/*!\fn GetMol()
+@return the molecule dispayed inside the document.
 */
-GCU_PROP (Display3DMode, Display3D)
 GCU_RO_PROP (Molecule *, Mol)
+
+private:
+	/* cell parameters to support molecule loaded from a crystal structure */
+	gdouble m_a, m_b, m_c, m_alpha, m_beta, m_gamma;
 };
 
 }	// namespace gcu
