@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * libs/gcu/cycle.cc 
+ * libs/gcu/cycle.cc
  *
- * Copyright (C) 2001-2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -27,6 +27,7 @@
 #include "atom.h"
 #include "bond.h"
 #include "molecule.h"
+#include <glib/gi18n-lib.h>
 
 namespace gcu {
 
@@ -216,4 +217,30 @@ int Cycle::GetFusedBonds ()
 	return n;
 }
 
+unsigned Cycle::GetBridgeLength (Cycle *c, Atom *atom, Bond *bond)
+{
+	unsigned n = 0;
+	if (m_Bonds[atom].fwd != bond)
+		Reverse ();
+	if (c->m_Bonds[atom].fwd != bond)
+		c->Reverse ();
+	Atom *cur = atom;
+	while (1) {
+		n++;
+		cur = m_Bonds[atom].fwd->GetAtom (cur);
+		if (cur == atom)
+			// the cycles are identical, this should not occur, but it's better
+			// if infinite loops are prevented
+			break;
+		if (m_Bonds[cur].fwd != c->m_Bonds[cur].fwd)
+			break;
+	}
+	return n;
+}
+
+std::string Cycle::Name ()
+{
+	return _("Cycle");
+}
+
 }	//	namespace gcu
