@@ -95,6 +95,14 @@ bool Document::SetTarget (char const *id, Object **target, Object *parent, Objec
 {
 	if (target == NULL)
 	    throw std::runtime_error ("Can't set a NULL target.");
+	if (parent) {
+		*target = parent->GetDescendant (id);
+		if (*target) {
+			if (owner)
+				owner->OnLoaded ();
+			return true;
+		}
+	}
 	PendingTarget pt;
 	pt.target = target;
 	pt.parent = parent;
@@ -169,4 +177,11 @@ std::string Document::Name ()
 	return _("Document");
 }
 
+std::string& Document::GetTranslatedId (const char* id)
+{
+	static std::string empty_string ("");
+	std::map < std::string, std::string >::iterator i = m_TranslationTable.find (id);
+	return (i != m_TranslationTable.end ())? (*i).second: empty_string;
+}
+
 }	//	namespace gcu
