@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * element.h 
+ * element.h
  *
- * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -25,15 +25,15 @@
 #ifndef GCU_ELEMENT_H
 #define GCU_ELEMENT_H
 
-#include <glib.h>
 #include <map>
 #include <string>
 #include <vector>
 #include "chemistry.h"
 #include "isotope.h"
 #include "value.h"
+#include "macros.h"
 
-/*!\file */ 
+/*!\file */
 /*!\def GCU_ERROR
 Defines a standard error value.
 */
@@ -78,7 +78,7 @@ public:
 	@param Z: the atomic number of a chemical element.
 	@return The chemical symbol of the element whose atomic number is Z or NULL if the element is unknown.
 	*/
-	static const gchar* Symbol (gint Z);
+	static const char* Symbol (int Z);
 	/*!
 	@param Z: the atomic number of a chemical element.
 
@@ -86,25 +86,25 @@ public:
 	attached hydrogens should be written.
 	@return true if hydrogens should be written on the right and false when it should be written on the left side.
 	*/
-	static bool BestSide (gint Z);
+	static bool BestSide (int Z);
 	/*!
 	@param symbol: the symbol of a chemical element.
 	@return The atomic number of the element whose chemical symbol is used as parameter or 0 if the element is unknown.
 	*/
-	static gint Z (const gchar* symbol);
+	static int Z (const char* symbol);
 	/*!
 	@param Z: the atomic number of a chemical element.
 	@return a pointer to the Element whose atomic number is Z or NULL if the element is unknown.
 	*/
-	static Element* GetElement (gint Z);
+	static Element* GetElement (int Z);
 	/*!
 	@param symbol: the symbol of a chemical element.
 	@return a pointer to the Element whose symbol is used as parameter or NULL if the element is unknown.
 	*/
-	static Element* GetElement (const gchar* symbol);
+	static Element* GetElement (const char* symbol);
 	/*!
 	@param radius: a pointer to a GcuAtomicRadius structure.
-	
+
 	Before calling this function, most fields in the GcuAtomicRadius structure must be filled:
 	- Z: the atomic number, mandatory
 	- type: the type of the radius searched
@@ -112,23 +112,23 @@ public:
 	- cn: the coordination number or -1 if not significant
 	- spin: the spin state or GCU_N_A_SPIN if not significant
 	- scale: the name of the scale (e.g. "Pauling") or NULL
-	
+
 	The programs searches a value corresponding to the fields having a non default value. If one is found
 	the other fields are given the corresponding values f the first match before returning.
-	
+
 	@return true if a radius has been found and false if not.
 	*/
 	static bool GetRadius (GcuAtomicRadius* radius);
 	/*!
 	@param en: a pointer to a GcuElectronegativity structure.
-	
+
 	Before calling this function, the following fields in the GcuElectronegativity structure must be filled:
 	- Z: the atomic number, mandatory
 	- type: the gcu_radius_type, mandatory
 	- charge: the charge of the atom, mandatory; must be 0 for non ionic radii
 	and non null for ionic radii.
 	- scale: the name of the scale (e.g. "Pauling") or NULL
-	
+
 	The programs searches an electronegativity value for the element in the scale if given. If one is found
 	the value and the scale (if NULL on calling)  are given the corresponding values of the first match before returning.
 
@@ -137,12 +137,12 @@ public:
 	static bool GetElectronegativity (GcuElectronegativity* en);
 	/*!
 	@param Z: the atomic number of a chemical element.
-	
+
 	The value returned by this method might be too low in some cases and is only indicative. Instances of the Atom class
 	accept any number of bonds. This behavior might change in future versions.
 	@return the maximum number of bonds an atom of the element can be involved in.
 	*/
-	static unsigned GetMaxBonds (gint Z);
+	static unsigned GetMaxBonds (int Z);
 	/*!
 	Loads the atomic radii database.
 	*/
@@ -163,6 +163,11 @@ public:
 	Loads all databases.
 	*/
 	static void LoadAllData ();
+	/*!
+	Intialize the element database. There is no need to call this method if
+	any of the Load*() method is called.
+	*/
+	static void Init ();
 
 	/*!
 	\return The atomic number of the chemical element.
@@ -303,6 +308,10 @@ private:
 	std::map<std::string, std::string> sprops;
 	std::map<std::string, int> iprops;
 	std::string ElecConfig;
+/*!\fn GetStability()
+@return true if the element has at least one stable isotope, false otherwise.
+*/
+GCU_RO_PROP (bool, Stability)
 };
 
 } // namespace gcu
