@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
  * gcu/objprops.h
  *
- * Copyright (C) 2007-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -119,6 +119,10 @@ The atomic number of an atom.
 The charge of an atom.
 */
 	GCU_PROP_ATOM_CHARGE,
+/*!
+The parity of an atom: a positive or negative integer followed by the ids of the four (or less) bonded atoms.
+*/
+	GCU_PROP_ATOM_PARITY,
 	// Bond properties
 /*!
 The Id of the atom at the first extremity of the bond.
@@ -129,11 +133,12 @@ The Id of the atom at the last extremity of the bond.
 */
 	GCU_PROP_BOND_END,
 /*!
+The bond order.
 */
 	GCU_PROP_BOND_ORDER,
 /*!
-The bond order.
-*/
+The bond type: normal, hash, wedge,...
+	 */
 	GCU_PROP_BOND_TYPE, //normal, hash, wedge,...
 	// Text properties
 /*!
