@@ -11,7 +11,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
 
  * This program is distributed in the hope that it will be useful,
@@ -505,7 +505,7 @@ find_by_id:
 	for (i = _SpaceGroups.sgs.begin(); i != end; i++)
 		if (**i == *group)
 			return *i;
-	cerr << _("Unknown space group error, please file a bug report.") << endl;;
+	cerr << _("Unknown space group error, please file a bug report.") << endl;
 	return NULL;
 }
 
