@@ -586,10 +586,14 @@ static int ReadField (char const *s, char *key, char *buf)
 			strncpy (buf, data, MIN (eq - data, VALUE_LENGTH));
 			buf[MIN (eq - data, VALUE_LENGTH - 1)] = 0;
 		}
-		else
+		else {
 			strncpy (buf, data, VALUE_LENGTH);
+			buf[VALUE_LENGTH - 1] = 0;
+		}
 		// strip trailing white spaces:
-		i = strlen (buf);
+		i = strlen (buf) - 1;
+		if (i < 0)
+			return JCAMP_UNKNOWN;
 		while (buf[i] <= ' ' || buf[i] == '"')
 			buf[i--] = 0;
 
@@ -1478,7 +1482,7 @@ void SpectrumDocument::ReadDataTable (istream &s, double *x, double *y)
 			break;	// this should not occur, but a corrupted or bad file is always possible
 		s.getline (line, 300);
 		if (strstr (line, "##")) {
-			s.seekg (-strlen (line) -1, _S_cur);
+			s.seekg (-strlen (line) -1, s.cur);
 			if (read > npoints) {
 				g_warning (_("Found too many data!"));
 				// FIXME: throw an exception
