@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -902,6 +902,13 @@ bool CDXMLLoader::WriteObject (xmlDocPtr xml, xmlNodePtr node, Object const *obj
 					either in this code or in the cml schema */
 }
 
+void CDXMLLoader::AddIntProperty (xmlNodePtr node, char const *id, int value)
+{
+	char *buf = g_strdup_printf ("%d", value);
+	xmlNewProp (node, reinterpret_cast <xmlChar const *> (id), reinterpret_cast <xmlChar *> (buf));
+	g_free (buf);
+}
+
 void CDXMLLoader::AddStringProperty (xmlNodePtr node, char const *id, string &value)
 {
 	xmlNewProp (node, reinterpret_cast <xmlChar const *> (id), reinterpret_cast <xmlChar const *> (value.c_str ()));
