@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint atoms plugin
- * orbitaltool.cc 
+ * orbitaltool.cc
  *
- * Copyright (C) 2009-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2009-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -35,7 +35,7 @@
 #include <gccv/circle.h>
 #include <gccv/group.h>
 #include <gccv/leaf.h>
-#include <gcu/ui-builder.h>
+#include <gcugtk/ui-builder.h>
 
 gcpOrbitalTool::gcpOrbitalTool (gcp::Application *App):
 	gcp::Tool (App, "Orbital"),
@@ -147,6 +147,8 @@ bool gcpOrbitalTool::OnClicked ()
 		m_Item = group;
 		break;
 	}
+	default:
+		break;
 	}
 	return true;
 }
@@ -166,7 +168,7 @@ void gcpOrbitalTool::OnRelease ()
 	if (!m_Item || !m_Item->GetVisible ())
 		return;
 	gcp::Atom *atom = static_cast <gcp::Atom *> (m_pObject);
-	gcu::Object *obj = m_pObject->GetParent ();
+	gcu::Object *obj = m_pObject->GetGroup ();
 	gcp::Document* doc = m_pView->GetDoc ();
 	gcp::Operation* op = doc-> GetNewOperation (gcp::GCP_MODIFY_OPERATION);
 	op->AddObject (obj, 0);
@@ -203,7 +205,7 @@ void gcpOrbitalTool::OnLeaveNotify ()
 
 GtkWidget *gcpOrbitalTool::GetPropertyPage ()
 {
-	gcu::UIBuilder *builder = new gcu::UIBuilder (UIDIR"/orbital.ui", GETTEXT_PACKAGE);
+	gcugtk::UIBuilder *builder = new gcugtk::UIBuilder (UIDIR"/orbital.ui", GETTEXT_PACKAGE);
 	m_CoefBtn = GTK_SPIN_BUTTON (builder->GetWidget ("coef-btn"));
 	gtk_spin_button_set_value (m_CoefBtn, m_Coef);
 	g_signal_connect_swapped (m_CoefBtn, "value-changed", G_CALLBACK (CoefChanged), this);
@@ -229,7 +231,7 @@ GtkWidget *gcpOrbitalTool::GetPropertyPage ()
 	m_Preview = new gccv::Canvas (NULL);
 	w = m_Preview->GetWidget ();
 	gtk_widget_show (w);
-	gtk_table_attach (GTK_TABLE (res), w, 1, 3, 3, 8, GTK_FILL, GTK_FILL, 10, 0);
+	gtk_grid_attach (GTK_GRID (res), w, 1, 3, 2, 5);
 	g_signal_connect_swapped (G_OBJECT (w), "size-allocate", G_CALLBACK (SizeAllocate), this);
 	delete builder;
 	return res;
@@ -355,5 +357,7 @@ void gcpOrbitalTool::UpdatePreview ()
 		m_PreviewItem = group;
 		break;
 	}
+	default:
+		break;
 	}
 }
