@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -163,7 +163,7 @@ bool gcpFragmentTool::OnClicked ()
 		m_Active->OnButtonPressed (m_x0, m_y0);
 		m_CurNode = m_Fragment->SaveSelected ();
 		m_InitNode = m_Fragment->SaveSelected ();
-		pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", false);
+		static_cast < gcp::Window * > (pDoc->GetWindow ())->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", false);
 		m_Fragment->SetEditor (this);
 	}
 	BuildTagsList ();
@@ -406,7 +406,7 @@ void gcpFragmentTool::BuildTagsList ()
 	}
 	m_Active->SetCurTagList (l);
 	if (m_pView)
-		gtk_window_present (m_pView->GetDoc ()->GetWindow ()->GetWindow ());
+		gtk_window_present (static_cast < gcugtk::Window * > (m_pView->GetDoc ()->GetWindow ())->GetWindow ());
 }
 
 void gcpFragmentTool::OnCommit (G_GNUC_UNUSED GtkIMContext *context, const gchar *str, gcpFragmentTool *tool)
