@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -86,24 +86,24 @@ static void on_help (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* window)
 	window->GetApp ()->OnHelp ();
 }
 
-static void on_web (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* window)
+static void on_web (GtkWidget *widget, gsvWindow* window)
 {
-	window->GetApp ()->OnWeb ();
+	window->GetApp ()->OnWeb (gtk_widget_get_screen (widget));
 }
 
-static void on_live_assistance (G_GNUC_UNUSED GtkWidget *widget, gsvWindow *Win)
+static void on_live_assistance (GtkWidget *widget, gsvWindow *Win)
 {
-	Win->GetApp ()->OnLiveAssistance ();
+	Win->GetApp ()->OnLiveAssistance (gtk_widget_get_screen (widget));
 }
 
-static void on_mail (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* window)
+static void on_mail (GtkWidget *widget, gsvWindow* window)
 {
-	window->GetApp ()->OnMail ();
+	window->GetApp ()->OnMail (gtk_widget_get_screen (widget));
 }
 
-static void on_bug (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* window)
+static void on_bug (GtkWidget *widget, gsvWindow* window)
 {
-	window->GetApp ()->OnBug ();
+	window->GetApp ()->OnBug (gtk_widget_get_screen (widget));
 }
 
 static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gsvWindow *Win)
@@ -115,7 +115,7 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gsvWindow *
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
-		"published by the Free Software Foundation; either version 2 of the\n"
+		"published by the Free Software Foundation; either version 3 of the\n"
 		"License, or (at your option) any later version.\n\n"
 		"This program is distributed in the hope that it will be useful,\n"
 		"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
