@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
  * programs/spectra/window.h
  *
- * Copyright (C) 2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -25,9 +25,7 @@
 #ifndef GSV_WINDOW_H
 #define GSV_WINDOW_H
 
-#include <gtk/gtkpagesetup.h>
-#include <gtk/gtkprintsettings.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 class gsvApplication;
 class gsvDocument;
@@ -41,16 +39,12 @@ public:
 
 	void OnFileOpen ();
 	void OnPageSetup ();
-	void OnFilePrint (bool preview);
 	void OnFileClose ();
-	void DoPrint (GtkPrintOperation *print, GtkPrintContext *context);
 	void OnCopy ();
 	void SetTitle (std::string const &title);
 
 private:
 	GtkWindow* m_Window;
-	GtkPrintSettings *m_PrintSettings;
-	GtkPageSetup *m_PageSetup;
 
 GCU_RO_PROP (gsvApplication *, App);
 GCU_RO_PROP (gsvView *, View);
