@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * programs/gchemtable-curve.cc 
+ * programs/gchemtable-curve.cc
  *
- * Copyright (C) 2005-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2013 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -28,7 +28,7 @@
 #include "gchemtable-data-allocator.h"
 #include <gcu/chemistry.h>
 #include <gcu/element.h>
-#include <gcu/print-setup-dlg.h>
+#include <gcugtk/print-setup-dlg.h>
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-output-memory.h>
 #include <gsf/gsf-output-gio.h>
@@ -41,6 +41,7 @@ using namespace gcu;
 using namespace std;
 
 map<string, GChemTableCurve*> curves;
+GObject *Copied;
 
 void on_show_curve (GObject *obj, char const* name)
 {
@@ -70,17 +71,21 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 	case 0: {
 			GsfXMLOut *xout;
 			char *old_num_locale, *old_monetary_locale;
-		
+
 			old_num_locale = g_strdup (go_setlocale (LC_NUMERIC, NULL));
 			go_setlocale (LC_NUMERIC, "C");
 			old_monetary_locale = g_strdup (go_setlocale (LC_MONETARY, NULL));
 			go_setlocale (LC_MONETARY, "C");
 			go_locale_untranslated_booleans ();
-		
+
+			GogObject *graph_;
+			graph_ = gog_object_dup (GOG_OBJECT (graph),
+				NULL, gog_dataset_dup_to_simple);
 			xout = gsf_xml_out_new (output);
-			gog_object_write_xml_sax (GOG_OBJECT (graph), xout, NULL);
+			gog_object_write_xml_sax (GOG_OBJECT (graph_), xout, NULL);
 			g_object_unref (xout);
-		
+			g_object_unref (graph_);
+
 			/* go_setlocale restores bools to locale translation */
 			go_setlocale (LC_MONETARY, old_monetary_locale);
 			g_free (old_monetary_locale);
@@ -102,7 +107,7 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 		true;
 	if (res) {
 		osize = gsf_output_size (output);
-				
+
 		buffer = (guchar*) g_malloc (osize);
 		memcpy (buffer, gsf_output_memory_get_bytes (omem), osize);
 		gsf_output_close (output);
@@ -117,6 +122,7 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 
 void on_clear_data(G_GNUC_UNUSED GtkClipboard *clipboard, GogGraph *graph)
 {
+	Copied = NULL;
 	g_object_unref (graph);
 }
 
@@ -169,27 +175,27 @@ static void on_help (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 
 static void on_curve_help (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
-	curve->Help ();
+	curve->GetApplication ()->OnHelp (curve->GetWindowName ());
 }
 
 static void on_web (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
-	curve->GetApplication ()->OnWeb ();
+	curve->GetApplication ()->OnWeb (gtk_widget_get_screen (widget));
 }
 
 static void on_live_assistance (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
-	curve->GetApplication ()->OnLiveAssistance ();
+	curve->GetApplication ()->OnLiveAssistance (gtk_widget_get_screen (widget));
 }
 
 static void on_mail (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
-	curve->GetApplication ()->OnMail ();
+	curve->GetApplication ()->OnMail (gtk_widget_get_screen (widget));
 }
 
 static void on_bug (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
-	curve->GetApplication ()->OnBug ();
+	curve->GetApplication ()->OnBug (gtk_widget_get_screen (widget));
 }
 
 static void on_about (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
@@ -264,11 +270,11 @@ static const char *ui_description =
 "</ui>";
 
 GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
-	Dialog (App, UIDIR"/curve.ui", "curvedlg", GETTEXT_PACKAGE),
-	Printable (),
+	gcugtk::Dialog (App, UIDIR"/curve.ui", "curvedlg", GETTEXT_PACKAGE),
+	gcugtk::Printable (),
 	m_Guru (NULL)
 {
-	m_GraphBox = GetWidget ("vbox1");
+	m_GraphBox = GetWidget ("curve-grid");
 	GtkUIManager *ui_manager = gtk_ui_manager_new ();
 	GtkActionGroup *action_group = gtk_action_group_new ("MenuActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
@@ -283,14 +289,15 @@ GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
 		exit (EXIT_FAILURE);
 	}
 	GtkWidget *bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
-	gtk_box_pack_start (GTK_BOX (m_GraphBox), bar, FALSE, FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (m_GraphBox), bar);
 	g_object_unref (ui_manager);
 	m_GraphWidget = go_graph_widget_new (NULL);
 	g_signal_connect_swapped (m_GraphWidget, "size-allocate", G_CALLBACK (GChemTableCurve::OnSize), this);
 	g_signal_connect_swapped (m_GraphWidget, "motion-notify-event", G_CALLBACK (GChemTableCurve::OnMotion), this);
 	gtk_widget_set_size_request (m_GraphWidget, 400, 250);
+	g_object_set (G_OBJECT (m_GraphWidget), "expand", true, NULL);
 	gtk_widget_show (m_GraphWidget);
-	gtk_box_pack_end (GTK_BOX (m_GraphBox), m_GraphWidget, TRUE, TRUE, 0);
+	gtk_container_add (GTK_CONTAINER (m_GraphBox), m_GraphWidget);
 	m_Graph = go_graph_widget_get_graph (GO_GRAPH_WIDGET (m_GraphWidget));
 	GogChart *chart = go_graph_widget_get_chart (GO_GRAPH_WIDGET (m_GraphWidget));
 	if (!name) {
@@ -331,7 +338,7 @@ GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
 		gtk_window_set_title (dialog, _("Electron affinity"));
 	} else if (!strncmp (name, "ei-", 3)) {
 		unsigned rank = strtol (name + 3, NULL, 10);
-		char *rk, *buf;		
+		char *rk, *buf;
 		switch (rank) {
 		case 1:
 			ydata = gct_data_vector_get_from_name (_("First ionization energy"));
@@ -452,13 +459,13 @@ void GChemTableCurve::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintC
 	w = m_GraphWidth;
 	h = m_GraphHeight;
 	switch (GetScaleType ()) {
-	case GCU_PRINT_SCALE_NONE:
+	case gcugtk::GCU_PRINT_SCALE_NONE:
 		break;
-	case GCU_PRINT_SCALE_FIXED:
+	case gcugtk::GCU_PRINT_SCALE_FIXED:
 		w *= Printable::GetScale ();
 		h *= Printable::GetScale ();
 		break;
-	case GCU_PRINT_SCALE_AUTO:
+	case gcugtk::GCU_PRINT_SCALE_AUTO:
 		if (GetHorizFit ())
 			w = width;
 		if (GetVertFit ())
@@ -478,13 +485,13 @@ void GChemTableCurve::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintC
 
 void GChemTableCurve::OnPageSetup ()
 {
-	new PrintSetupDlg (m_App, this);
+	new gcugtk::PrintSetupDlg (GetApplication (), this);
 }
 
 void GChemTableCurve::OnCopy ()
 {
 	GtkClipboard* clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
-	g_object_ref (m_Graph);
+	Copied = G_OBJECT (g_object_ref (m_Graph));
 	gtk_clipboard_set_with_data (clipboard, targets, 4,
 		(GtkClipboardGetFunc) on_get_data, (GtkClipboardClearFunc) on_clear_data, m_Graph);
 }
@@ -531,8 +538,12 @@ void GChemTableCurve::SetGraph (GogGraph *graph)
 {
 	gtk_widget_destroy (m_GraphWidget);
 	m_GraphWidget = go_graph_widget_new (graph);
+	g_signal_connect_swapped (m_GraphWidget, "size-allocate", G_CALLBACK (GChemTableCurve::OnSize), this);
+	g_signal_connect_swapped (m_GraphWidget, "motion-notify-event", G_CALLBACK (GChemTableCurve::OnMotion), this);
+	gtk_widget_set_size_request (m_GraphWidget, 400, 250);
+	g_object_set (G_OBJECT (m_GraphWidget), "expand", true, NULL);
 	gtk_widget_show (m_GraphWidget);
-	gtk_box_pack_end (GTK_BOX (m_GraphBox), m_GraphWidget, TRUE, TRUE, 0);
+	gtk_container_add (GTK_CONTAINER (m_GraphBox), m_GraphWidget);
 	m_Graph = go_graph_widget_get_graph (GO_GRAPH_WIDGET (m_GraphWidget));
 }
 
